@@ -24,9 +24,6 @@ from rest_registration.utils.users import (
     user_with_email_exists
 )
 from rest_registration.utils.verification import verify_signer_or_bad_request
-from rest_registration.verification_notifications import (
-    send_register_email_verification_email_notification
-)
 
 
 @api_view_serializer_class_getter(
@@ -53,8 +50,8 @@ def register_email(request: Request) -> Response:
     email_already_used = is_user_email_field_unique() and user_with_email_exists(email)
 
     if registration_settings.REGISTER_EMAIL_VERIFICATION_ENABLED:
-        send_register_email_verification_email_notification(
-            request, user, email, email_already_used=email_already_used)
+        email_sender = registration_settings.REGISTER_EMAIL_VERIFICATION_EMAIL_SENDER
+        email_sender(request, user, email, email_already_used=email_already_used)
     else:
         if email_already_used:
             raise EmailAlreadyRegistered()
@@ -103,7 +100,9 @@ def process_verify_email_data(
     serializer.is_valid(raise_exception=True)
 
     data = serializer.validated_data
-    signer = RegisterEmailSigner(data)
+    # We use the signer only for verification, therefore we don't need a base_url and
+    # may set strict=False
+    signer = RegisterEmailSigner(data, strict=False)
     verify_signer_or_bad_request(signer)
     request = serializer_context.get('request')
     new_email = data['email']
